==> carp_context_package-0.12.1.tar.gz: lib/src/mobility/mobility_datum.dart <==
part of context;

/// A [Datum] that holds mobility features information.
@JsonSerializable(fieldRename: FieldRename.snake, includeIfNull: false)
class MobilityDatum extends CARPDatum {
  static const DataFormat CARP_DATA_FORMAT =
      DataFormat(NameSpace.CARP, ContextSamplingPackage.MOBILITY);

  DataFormat get format => CARP_DATA_FORMAT;

  /// The day of this mobility features.
  DateTime date;

  /// The timestamp at which the features were computed.
  DateTime timestamp;

  /// Number of places visited on [date].
  int numberOfPlaces;

  /// Location Variance on [date].
  double locationVariance;

  /// Location entropy
  ///  * High entropy: Time is spent evenly among all places
  ///  * Low  entropy: Time is mainly spent at a few of the places
  double entropy;

  /// Normalized entropy. A scalar between 0 and 1
  double normalizedEntropy;

  /// Home Stay today. A scalar between 0 and 1, i.e. from 0% to 100%
  double homeStay;

  /// Distance travelled today, in meters.
  double distanceTravelled;

  MobilityDatum() : super();

  factory MobilityDatum.fromJson(Map<String, dynamic> json) =>
      _$MobilityDatumFromJson(json);

  Map<String, dynamic> toJson() => _$MobilityDatumToJson(this);

  String toString() =>
      super.toString() +
      ',number of places: $numberOfPlaces\n' +
      'location variance: $locationVariance\n' +
      'entropy: $entropy\n' +
      'normalized entropy: $normalizedEntropy\n' +
      'home stay: $homeStay\n' +
      'distance travelled: $distanceTravelled\n';
}

==> carp_context_package-0.31.2.tar.gz: lib/src/mobility/mobility_datum.dart <==
part of context;

/// A [Datum] that holds mobility features information.
@JsonSerializable(fieldRename: FieldRename.snake, includeIfNull: false)
class MobilityDatum extends Datum {
  DataFormat get format =>
      DataFormat.fromString(ContextSamplingPackage.MOBILITY);

  /// The day of this mobility features.
  late DateTime date;

  /// The timestamp at which the features were computed.
  DateTime? timestamp;

  /// Number of places visited on [date].
  int? numberOfPlaces;

  /// Location Variance on [date].
  double? locationVariance;

  /// Location entropy
  ///  * High entropy: Time is spent evenly among all places
  ///  * Low  entropy: Time is mainly spent at a few of the places
  double? entropy;

  /// Normalized entropy. A scalar between 0 and 1
  double? normalizedEntropy;

  /// Home Stay today. A scalar between 0 and 1, i.e. from 0% to 100%
  double? homeStay;

  /// Distance travelled today, in meters.
  double? distanceTravelled;

  MobilityDatum() : super();

  factory MobilityDatum.fromMobilityContext(MobilityContext context) =>
      MobilityDatum()
        ..numberOfPlaces = context.numberOfSignificantPlaces
        ..homeStay = context.homeStay
        ..distanceTravelled = context.distanceTravelled
        ..entropy = context.entropy
        ..normalizedEntropy = context.normalizedEntropy
        ..locationVariance = context.locationVariance;

  factory MobilityDatum.fromJson(Map<String, dynamic> json) =>
      _$MobilityDatumFromJson(json);

  Map<String, dynamic> toJson() => _$MobilityDatumToJson(this);

  String toString() =>
      super.toString() +
      ',number of places: $numberOfPlaces\n' +
      'location variance: $locationVariance\n' +
      'entropy: $entropy\n' +
      'normalized entropy: $normalizedEntropy\n' +
      'home stay: $homeStay\n' +
      'distance travelled: $distanceTravelled\n';
}
